from azure.eventhub import EventHubConsumerClient
import json

import utils

# Read the config file
with open("config_DEV.json", "r") as f:
    config = json.load(f)

print(f"Event hub connection string: {config['event_hub_connection_str']}")
print(f"Event hub name: {config['event_hub_name']}")
print(f"Event hub consumer group: {config['event_hub_consumer_group']}")

# Create the client object that will consume events from Event Hub
client = EventHubConsumerClient.from_connection_string(
    config['event_hub_connection_str'],
    config['event_hub_consumer_group'],
    eventhub_name=config['event_hub_name']
)
print("Client created")


# Define the callback function
def on_event(partition_context, event):
    print("Received event from partition: ", partition_context.partition_id)
    print("Event body: ", event.body_as_str())
    print("Event properties: ", event.properties)
    print("Event sequence number: ", event.sequence_number)
    print("Event offset: ", event.offset)
    print("Event enqueued time: ", event.enqueued_time)

    # TODO invoke job1
    utils.trigger_job(config, config['job1_id'])
    # TODO invoke job2

    # Update the checkpoint so that the app doesn't read the same event again
    # partition_context.update_checkpoint(event)


# Listen continuously for events on the EventHub
print("Listening for events...")
with client:
    client.receive(on_event=on_event)
