from azure.keyvault.secrets import SecretClient
from azure.identity import DefaultAzureCredential
import requests
import json


def read_secret_from_keyvault(vault_url, secret_name):
    # Create a secret client
    client = SecretClient(vault_url=vault_url, credential=DefaultAzureCredential())

    # Get the secret value
    secret_value = client.get_secret(secret_name).value

    return secret_value


def trigger_job(config, job_id):
    # Construct the API request URL - get url and path from config file
    api_url = f"{config['workspace_url']}{config['run_job_api_path']}"

    # TODO: Get the access token from key vault
    # access_token = read_secret_from_keyvault(config['key_vault_url'], config['access_token_secret_name'])

    # Set the request headers
    headers = {
        "Authorization": f"Bearer {config['access_token']}",
        "Content-Type": "application/json"
    }

    # Trigger the job, i.e. make the API request
    response = requests.post(api_url, headers=headers, json={"job_id": job_id})

    # Handle the response
    if response.status_code == 200:
        print("Job successfully triggered")

        # Parse the response JSON
        response_json = json.loads(response.text)
        run_id = response_json["run_id"]
        print("Run ID: ", run_id)
    else:
        print(f"Error triggering job: {response.text}")


def invoke_job(environment, job_id):
    # Read the config file
    config_file = f"config_{environment}.json"
    with open(config_file, "r") as f:
        config = json.load(f)

    # Trigger the job
    trigger_job(config, job_id)
